pub enum StrOrDoc<'p> {
S(Cow<'p, str>),
D(DocPtr<'p>),
}Expand description
A tagged union of either a Cow string, or a DocPtr. By using
this type in conjuction with the Doclike trait, we get a pretty
large amount of code reuse while cutting down on syntax noise
since in many cases we can treat string slices, owned strings,
and DocPtr items in the exact same way with the only overhead
being that of dealing with the enum (IE there are no extra
allocations or clones).
Variants